==> jmb.fax-0.3.2.tar.gz: jmb.fax-0.3.2/jmb/fax/views.py <==
# coding: utf-8
from django.conf import settings
from django import forms
from django.contrib.auth.decorators import login_required
from django.utils import simplejson
from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.core.files.uploadedfile import SimpleUploadedFile
from django.utils.translation import ugettext as _
from django.forms.models import modelformset_factory, inlineformset_factory
from django.views.decorators.csrf import csrf_exempt
from django.views.static import serve
from django.core.urlresolvers import reverse

from jmb.core.shortcuts import render_to_response, render_to_string
from jmb.fax.models import Fax, Cover, FaxPermission, Document
#from jmb.fax.forms import FaxSendForm, FaxForm, FaxScanForm, CoverFormInline
from jmb.fax import kpn

@csrf_exempt
def kpnparse(request, *args, **kwargs):

   csrf_exempt = True
   xml = request.raw_post_data
   if xml.startswith('<?xml'):
       # xml from kpn can just be a 'ping' or a status notification
       if not 'ping' in xml:
           kpn.update_status(xml)
   else:
       pass

   return HttpResponse('', status=202)

@csrf_exempt
def setup(request, *args, **kwargs):

   from jmb.fax.kpn import kpn_send
   suds_client, auth = kpn_send.setup(
       'faxtest@thundersystems.it', 'magenopa',  'http://casa.e-den.it:8080/fax/kpnparse/')
   return HttpResponse(str(auth), status=200)

def check_send_permission(user):
   if user.has_perm("fax.send_all_fax"):
       return True

   list_lperms = FaxPermission.objects.filter(codename__startswith='send')
   for perm in list_lperms:
       if user.has_perm("fax.%s" % perm.codename):
           return True

   return False

@login_required
def download_pdf(request, object_id):

    if request.user.has_perm("fax.download_document"):
       try:
          doc = Document.objects.get(id=object_id)
          doc.fax.mark_as_read()
          # cambio lo stato da Non letto a letto
          doc.fax.mark_as_read()
          doc.fax.save()
          return serve(request, doc.file.path, '/') 
       except Exception, e:
          return HttpResponseNotFound(render_to_string('admin/fax/fax/error_report.html', error=e))
    else:
        return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))


@login_required
def report_pdf(request, object_id):

    from reportlab.pdfgen import canvas
    from django.http import HttpResponse

    if not request.user.has_perm("fax.view_reports"):
       return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    response = HttpResponse(mimetype='application/pdf')

    p = canvas.Canvas(response)
    fax = Fax.objects.get(pk=object_id)

    response['Content-Disposition'] = 'attachment; filename=report_%s.pdf' % fax.id

    date_fax = fax.date_last_modify.strftime('%d/%m/%Y %H:%M:%S')
    date_sent = fax.date_sent and fax.date_sent.strftime('%d/%m/%Y %H:%M:%S')

    if fax.status == 2:
        p.drawString(30, 800, _('Sender: %s' % fax.sender))
        p.drawString(30, 780, _('Job ID: %s' % fax.job))
        p.drawString(30, 760, _('Received Date: %s' % date_fax))
        p.drawString(30, 740, _('Received Time: %s' % fax.duration))
        p.drawString(30, 720, _('Received Pages: %s' % fax.pages))

    elif fax.status in (4, 5): #sent or failed
        if fax.status == 4:
            confirm = 'OK'
        else:
            confirm = fax.error

        dest = "%s" % fax.recipient_number
        if fax.recipient:
            dest = "%s (%s)" % (fax.recipient, fax.recipient_number)

        p.drawString(30, 800, _('Recipient: %s' % dest))
        p.drawString(30, 780, _('Subject: %s' % fax.subject))
        p.drawString(30, 760, _('Job ID: %s' % fax.job))
        p.drawString(30, 740, _('Sent Date: %s' % date_sent))
        p.drawString(30, 720, _('Sent Confirm: %s' % confirm))
        p.drawString(30, 700, _('Sent Time: %s' % fax.duration))
        p.drawString(30, 680, _('Sent Pages: %s' % fax.pages))

    p.showPage()
    p.save()

    return response

def download_cover(request, object_id):

    if request.user.has_perm("fax.add_cover"):
        try:
            fax = Fax.objects.get(id=object_id)
            if not fax.has_cover():
                return render_to_string(
                    'admin/fax/fax/error_report.html',
                    error="Non e' stata inviata nessuna cover con questo fax"
                )
        except Exception, e:
            return HttpResponseNotFound(render_to_string('admin/fax/fax/error_report.html', error=e))
    else:
        return HttpResponseForbidden(render_to_string('jumbo/forbidden.html'))

    extra_context = {'fax':fax, 'cover': fax.cover, }
    path = fax.cover.save_as_pdf(ps=False)
    return serve(request, path, '/')

==> jmb.fax-0.6.tar.gz: jmb.fax-0.6/jmb/fax/views.py <==
# coding: utf-8
from __future__ import unicode_literals

from django.conf import settings
from django import forms
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden
from django.core.files.uploadedfile import SimpleUploadedFile
from django.utils.translation import ugettext as _
from django.forms.models import modelformset_factory, inlineformset_factory
from django.views.decorators.csrf import csrf_exempt
from django.views.static import serve
from django.core.urlresolvers import reverse

from jmb.core.shortcuts import render_to_response, render_to_string
from jmb.fax.models import Fax, Cover, FaxPermission, Document
#from jmb.fax.forms import FaxSendForm, FaxForm, FaxScanForm, CoverFormInline
from jmb.fax import kpn

@csrf_exempt
def kpnparse(request, *args, **kwargs):

    csrf_exempt = True
    xml = request.raw_post_data
    if xml.startswith('<?xml'):
        # xml from kpn can just be a 'ping' or a status notification
        if not 'ping' in xml:
            kpn.update_status(xml)
    else:
        pass

    return HttpResponse('', status=202)

@csrf_exempt
def setup(request, *args, **kwargs):

    from jmb.fax.kpn import kpn_send
    suds_client, auth = kpn_send.setup(
        'faxtest@thundersystems.it', 'magenopa',  'http://casa.e-den.it:8080/fax/kpnparse/')
    return HttpResponse(str(auth), status=200)

def check_send_permission(user):
    if user.has_perm("fax.send_all_fax"):
        return True

    list_lperms = FaxPermission.objects.filter(codename__startswith='send')
    for perm in list_lperms:
        if user.has_perm("fax.%s" % perm.codename):
            return True

    return False

@login_required
def download_pdf(request, object_id):

    try:
        doc = Document.objects.get(id=object_id)
    except Document.DoesNotExist as e:

        return HttpResponseNotFound(render_to_string('admin/fax/fax/error_report.html', error=e))

    if doc.can_download(request.user):
        doc.fax.mark_as_read()
        # cambio lo stato da Non letto a letto
        doc.fax.mark_as_read()
        doc.fax.save()
        return serve(request, doc.file.path, '/')
    else:
        return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))


@login_required
def report_pdf(request, object_id):

    from reportlab.pdfgen import canvas
    from django.http import HttpResponse

    if not request.user.has_perm("fax.download_all_report"):
        return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))

    response = HttpResponse(content_type='application/pdf')

    p = canvas.Canvas(response)
    fax = Fax.objects.get(pk=object_id)

    response['Content-Disposition'] = 'attachment; filename=report_%s.pdf' % fax.id

    date_fax = fax.date_last_modify.strftime('%d/%m/%Y %H:%M:%S')
    date_sent = fax.date_sent and fax.date_sent.strftime('%d/%m/%Y %H:%M:%S')

    if fax.status == 2:
        p.drawString(30, 800, _('Sender: %s' % fax.sender))
        p.drawString(30, 780, _('Job ID: %s' % fax.job))
        p.drawString(30, 760, _('Received Date: %s' % date_fax))
        p.drawString(30, 740, _('Received Time: %s' % fax.duration))
        p.drawString(30, 720, _('Received Pages: %s' % fax.pages))

    elif fax.status in (4, 5):  # sent or failed
        if fax.status == 4:
            confirm = 'OK'
        else:
            confirm = fax.error

        dest = "%s" % fax.recipient_number
        if fax.recipient:
            dest = "%s (%s)" % (fax.recipient, fax.recipient_number)

        p.drawString(30, 800, _('Recipient: %s' % dest))
        p.drawString(30, 780, _('Subject: %s' % fax.subject))
        p.drawString(30, 760, _('Job ID: %s' % fax.job))
        p.drawString(30, 740, _('Sent Date: %s' % date_sent))
        p.drawString(30, 720, _('Sent Confirm: %s' % confirm))
        p.drawString(30, 700, _('Sent Time: %s' % fax.duration))
        p.drawString(30, 680, _('Sent Pages: %s' % fax.pages))

    p.showPage()
    p.save()

    return response

def download_cover(request, object_id):

    if request.user.has_perm("fax.add_cover"):
        try:
            fax = Fax.objects.get(id=object_id)
            if not fax.has_cover():
                return render_to_string(
                    'admin/fax/fax/error_report.html',
                    error="Non e' stata inviata nessuna cover con questo fax"
                )
        except Exception as e:
            return HttpResponseNotFound(render_to_string('admin/fax/fax/error_report.html', error=e))
    else:
        return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))

    extra_context = {'fax': fax, 'cover': fax.cover, }
    path = fax.cover.save_as_pdf().name
    return serve(request, path, '/')
